;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "universal-sidecar-citeproc" "20251029.1934"
  "Centralise Citeproc Support for Universal Sidecar."
  '((emacs    "28.1")
    (citeproc "0.9.4"))
  :url "https://git.sr.ht/~swflint/emacs-universal-sidecar"
  :commit "01b12aecca0ce66f5427e7fe65012d37e7e128b2"
  :revdesc "01b12aecca0c"
  :keywords '("bib" "convenience")
  :authors '(("Samuel W. Flint" . "me@samuelwflint.com"))
  :maintainers '(("Samuel W. Flint" . "me@samuelwflint.com")))
